##
##  nats-server.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_nats_server_base  2.11.1
%define       V_nats_server_snap  20250401

#   package information
Name:         nats-server
Summary:      NATS Messaging Server
URL:          http://nats.io/
Vendor:       Apcera Inc.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      Apache
Version:      %{V_nats_server_base}.%{V_nats_server_snap}
Release:      20250401

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/nats/nats-server-%{V_nats_server_snap}.tar.xz
Source1:      rc.nats-server
Source2:      nats-server.conf
Source3:      nats-tls.sh

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101, cfssl

%description
    NATS is an open source, lightweight, high-performance cloud native
    infrastructure messaging system. It implements a highly scalable
    and elegant publish-subscribe (pub/sub) model with optional
    request/response semantics. The performant nature of NATS make it
    an ideal base for building modern, reliable, scalable cloud native
    distributed systems. This is the high-performance server for NATS,
    working as an in-memory message queue and optionally supporting
    clustering.

%track
    prog nats-server:base = {
        version   = %{V_nats_server_base}
        url       = https://github.com/nats-io/nats-server/releases
        regex     = nats-server-v(\d+\.\d+\.\d+)
    }
    prog nats-server:snap = {
        version   = %{V_nats_server_snap}
        url       = http://download.openpkg.org/components/versioned/nats/
        regex     = nats-server-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n nats-server

%build
    #   build program
    (   export GOPATH=`pwd`
        cd $GOPATH/src/github.com/nats-io/nats-server
        go build -v
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/nats-server \
        $RPM_BUILD_ROOT%{l_prefix}/var/nats-server/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/nats-server/log

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/nats-io/nats-server/nats-server \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/nats-server
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        -e 's;@l_bash@;%{l_bash};g' \
        %{SOURCE nats-tls.sh} $RPM_BUILD_ROOT%{l_prefix}/sbin/nats-tls

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.nats-server} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE nats-server.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/nats-server/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/nats-server/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/nats-server/*'

%files -f files

%clean

%post
    if [ $1 -eq 1 ]; then
        #   on initial installation, generate TLS certificate/key pair
        echo "Generating TLS Certificates/Keys" | %{l_rpmtool} msg -b -t notice
        $RPM_INSTALL_PREFIX/sbin/nats-tls localhost 127.0.0.1
        ( echo "NATS-Server was configured with a standard TLS certificate/key pair."
          echo "for \"localhost\" and \"127.0.0.1\". For production use, you usually let"
          echo "NATS-Server listen on an external IP address. For this the TLS"
          echo "certificate/key pair has to be regenerated with for instance:"
          echo "    \$ $RPM_INSTALL_PREFIX/sbin/nats-tls www.example.com 192.168.0.1"
        ) | %{l_rpmtool} msg -b -t notice
    elif [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} nats-server status 2>/dev/null`
        [ ".$nats_server_active" = .yes ] && %{l_rc} nats-server restart
    fi
    exit 0

%preun
    if [ $1 -eq 0 ]; then
        #   before erase, stop service and remove log files
        %{l_rc} nats-server stop 2>/dev/null
        rm -f  $RPM_INSTALL_PREFIX/etc/nats-server/ca.*     >/dev/null 2>&1 || true
        rm -f  $RPM_INSTALL_PREFIX/etc/nats-server/server.* >/dev/null 2>&1 || true
        rm -rf $RPM_INSTALL_PREFIX/var/nats-server/log/*    >/dev/null 2>&1 || true
        rm -rf $RPM_INSTALL_PREFIX/var/nats-server/run/*    >/dev/null 2>&1 || true
    fi
    exit 0

